/**
 * Copyright (c) HashiCorp, Inc.
 * SPDX-License-Identifier: MPL-2.0
 */
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface DynamicHostVolumeConfig extends cdktf.TerraformMetaArguments {
    /**
    * Requested maximum capacity
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#capacity_max DynamicHostVolume#capacity_max}
    */
    readonly capacityMax?: string;
    /**
    * Requested minimum capacity
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#capacity_min DynamicHostVolume#capacity_min}
    */
    readonly capacityMin?: string;
    /**
    * Volume name
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#name DynamicHostVolume#name}
    */
    readonly name: string;
    /**
    * Volume namespace
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#namespace DynamicHostVolume#namespace}
    */
    readonly namespace?: string;
    /**
    * Node ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#node_id DynamicHostVolume#node_id}
    */
    readonly nodeId?: string;
    /**
    * Node pool
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#node_pool DynamicHostVolume#node_pool}
    */
    readonly nodePool?: string;
    /**
    * Parameters
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#parameters DynamicHostVolume#parameters}
    */
    readonly parameters?: {
        [key: string]: string;
    };
    /**
    * Plugin ID
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#plugin_id DynamicHostVolume#plugin_id}
    */
    readonly pluginId: string;
    /**
    * capability block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#capability DynamicHostVolume#capability}
    */
    readonly capability: DynamicHostVolumeCapability[] | cdktf.IResolvable;
    /**
    * constraint block
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#constraint DynamicHostVolume#constraint}
    */
    readonly constraint?: DynamicHostVolumeConstraint[] | cdktf.IResolvable;
}
export interface DynamicHostVolumeCapability {
    /**
    * An access mode available for the volume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#access_mode DynamicHostVolume#access_mode}
    */
    readonly accessMode: string;
    /**
    * An attachment mode available for the volume.
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#attachment_mode DynamicHostVolume#attachment_mode}
    */
    readonly attachmentMode: string;
}
export declare function dynamicHostVolumeCapabilityToTerraform(struct?: DynamicHostVolumeCapability | cdktf.IResolvable): any;
export declare function dynamicHostVolumeCapabilityToHclTerraform(struct?: DynamicHostVolumeCapability | cdktf.IResolvable): any;
export declare class DynamicHostVolumeCapabilityOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DynamicHostVolumeCapability | cdktf.IResolvable | undefined;
    set internalValue(value: DynamicHostVolumeCapability | cdktf.IResolvable | undefined);
    private _accessMode?;
    get accessMode(): string;
    set accessMode(value: string);
    get accessModeInput(): string | undefined;
    private _attachmentMode?;
    get attachmentMode(): string;
    set attachmentMode(value: string);
    get attachmentModeInput(): string | undefined;
}
export declare class DynamicHostVolumeCapabilityList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DynamicHostVolumeCapability[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DynamicHostVolumeCapabilityOutputReference;
}
export interface DynamicHostVolumeConstraint {
    /**
    * An attribute to check to constrain volume placement
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#attribute DynamicHostVolume#attribute}
    */
    readonly attribute: string;
    /**
    * The operator to use for comparison
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#operator DynamicHostVolume#operator}
    */
    readonly operator?: string;
    /**
    * The requested value of the attribute
    *
    * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#value DynamicHostVolume#value}
    */
    readonly value?: string;
}
export declare function dynamicHostVolumeConstraintToTerraform(struct?: DynamicHostVolumeConstraint | cdktf.IResolvable): any;
export declare function dynamicHostVolumeConstraintToHclTerraform(struct?: DynamicHostVolumeConstraint | cdktf.IResolvable): any;
export declare class DynamicHostVolumeConstraintOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    private resolvableValue?;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param complexObjectIndex the index of this item in the list
    * @param complexObjectIsFromSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, complexObjectIndex: number, complexObjectIsFromSet: boolean);
    get internalValue(): DynamicHostVolumeConstraint | cdktf.IResolvable | undefined;
    set internalValue(value: DynamicHostVolumeConstraint | cdktf.IResolvable | undefined);
    private _attribute?;
    get attribute(): string;
    set attribute(value: string);
    get attributeInput(): string | undefined;
    private _operator?;
    get operator(): string;
    set operator(value: string);
    resetOperator(): void;
    get operatorInput(): string | undefined;
    private _value?;
    get value(): string;
    set value(value: string);
    resetValue(): void;
    get valueInput(): string | undefined;
}
export declare class DynamicHostVolumeConstraintList extends cdktf.ComplexList {
    protected terraformResource: cdktf.IInterpolatingParent;
    protected terraformAttribute: string;
    protected wrapsSet: boolean;
    internalValue?: DynamicHostVolumeConstraint[] | cdktf.IResolvable;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    * @param wrapsSet whether the list is wrapping a set (will add tolist() to be able to access an item via an index)
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string, wrapsSet: boolean);
    /**
    * @param index the index of the item to return
    */
    get(index: number): DynamicHostVolumeConstraintOutputReference;
}
/**
* Represents a {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume nomad_dynamic_host_volume}
*/
export declare class DynamicHostVolume extends cdktf.TerraformResource {
    static readonly tfResourceType = "nomad_dynamic_host_volume";
    /**
    * Generates CDKTF code for importing a DynamicHostVolume resource upon running "cdktf plan <stack-name>"
    * @param scope The scope in which to define this construct
    * @param importToId The construct id used in the generated config for the DynamicHostVolume to import
    * @param importFromId The id of the existing DynamicHostVolume that should be imported. Refer to the {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume#import import section} in the documentation of this resource for the id to use
    * @param provider? Optional instance of the provider where the DynamicHostVolume to import is found
    */
    static generateConfigForImport(scope: Construct, importToId: string, importFromId: string, provider?: cdktf.TerraformProvider): cdktf.ImportableResource;
    /**
    * Create a new {@link https://registry.terraform.io/providers/hashicorp/nomad/2.5.0/docs/resources/dynamic_host_volume nomad_dynamic_host_volume} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options DynamicHostVolumeConfig
    */
    constructor(scope: Construct, id: string, config: DynamicHostVolumeConfig);
    get capacity(): string;
    get capacityBytes(): number;
    private _capacityMax?;
    get capacityMax(): string;
    set capacityMax(value: string);
    resetCapacityMax(): void;
    get capacityMaxInput(): string | undefined;
    get capacityMaxBytes(): number;
    private _capacityMin?;
    get capacityMin(): string;
    set capacityMin(value: string);
    resetCapacityMin(): void;
    get capacityMinInput(): string | undefined;
    get capacityMinBytes(): number;
    get hostPath(): string;
    get id(): string;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _namespace?;
    get namespace(): string;
    set namespace(value: string);
    resetNamespace(): void;
    get namespaceInput(): string | undefined;
    private _nodeId?;
    get nodeId(): string;
    set nodeId(value: string);
    resetNodeId(): void;
    get nodeIdInput(): string | undefined;
    private _nodePool?;
    get nodePool(): string;
    set nodePool(value: string);
    resetNodePool(): void;
    get nodePoolInput(): string | undefined;
    private _parameters?;
    get parameters(): {
        [key: string]: string;
    };
    set parameters(value: {
        [key: string]: string;
    });
    resetParameters(): void;
    get parametersInput(): {
        [key: string]: string;
    } | undefined;
    private _pluginId?;
    get pluginId(): string;
    set pluginId(value: string);
    get pluginIdInput(): string | undefined;
    get state(): string;
    private _capability;
    get capability(): DynamicHostVolumeCapabilityList;
    putCapability(value: DynamicHostVolumeCapability[] | cdktf.IResolvable): void;
    get capabilityInput(): cdktf.IResolvable | DynamicHostVolumeCapability[] | undefined;
    private _constraint;
    get constraint(): DynamicHostVolumeConstraintList;
    putConstraint(value: DynamicHostVolumeConstraint[] | cdktf.IResolvable): void;
    resetConstraint(): void;
    get constraintInput(): cdktf.IResolvable | DynamicHostVolumeConstraint[] | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
    protected synthesizeHclAttributes(): {
        [name: string]: any;
    };
}
